==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>לסיים את המשחק הנוכחי?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;מושהה&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק כדי לחזור למשחק.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;המשחק נגמר!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק כדי להתחיל משחק חדש.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>אנא אתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>תוצאות Gottet</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>שורות</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>הקלק כדי להתחיל משחק חדש.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהה</translation>
    </message>
    <message>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>ח&amp;זור</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;תוצאות</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>חתיכה הבאה</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>שורות שהוסרו</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>חיקוי משחק טטריס שהכנתי עבור אשתי</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>לסיים את המשחק הנוכחי?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;מושהה&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק כדי לחזור למשחק.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;המשחק נגמר!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;הקלק כדי להתחיל משחק חדש.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>אנא אתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>שורות</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>הקלק כדי להתחיל משחק חדש.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהה</translation>
    </message>
    <message>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;תוצאות</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>חתיכה הבאה</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>שלב</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>שורות שהוסרו</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
